@@ -23,7 +23,7 @@ require Exporter;
 @ISA       = qw(Exporter);
 @EXPORT_OK = qw(fcopy rcopy dircopy fmove rmove dirmove pathmk pathrm pathempty pathrmdir rcopy_glob rmove_glob);
 
-$VERSION = '0.44';
+$VERSION = '0.45';
 
 $MaxDepth = 0;
 $KeepMode = 1;
@@ -277,7 +277,6 @@ sub dircopy {
                 my $rc;
                 if ( !-w $org && $KeepMode ) {
                     local $KeepMode = 0;
-                    carp "Copying readonly directory ($org); mode of its contents may not be preserved.";
                     $rc = $recurs->( $org, $new, $buf ) if defined $buf;
                     $rc = $recurs->( $org, $new ) if !defined $buf;
                     chmod scalar( ( stat($org) )[2] ), $new;
@@ -371,7 +370,7 @@ sub pathempty {
     my $pth = shift;
 
     my ( $orig_dev, $orig_ino ) = ( lstat $pth )[ 0, 1 ];
-    return 2 if !-d _ || !$orig_dev || ( $^O ne 'MSWin32' && !$orig_ino );    #stat.inode is 0 on Windows
+    return 2 if !-d _ || !defined($orig_dev) || ( $^O ne 'MSWin32' && !$orig_ino );    #stat.inode is 0 on Windows
 
     my $starting_point = Cwd::cwd();
     my ( $starting_dev, $starting_ino ) = ( lstat $starting_point )[ 0, 1 ];
@@ -421,7 +420,7 @@ sub pathrm {
     my ( $path, $force, $nofail ) = @_;
 
     my ( $orig_dev, $orig_ino ) = ( lstat $path )[ 0, 1 ];
-    return 2 if !-d _ || !$orig_dev || !$orig_ino;
+    return 2 if !-d _ || !defined($orig_dev) || !$orig_ino;
 
     # Manual test (I hate this function :/):
     #    sudo mkdir /foo && perl -MFile::Copy::Recursive=pathrm -le 'print pathrm("/foo",1)' && sudo rm -rf /foo
@@ -471,7 +470,7 @@ sub pathrmdir {
     }
 
     my ( $orig_dev, $orig_ino ) = ( lstat $dir )[ 0, 1 ];
-    return 2 if !$orig_dev || ( $^O ne 'MSWin32' && !$orig_ino );
+    return 2 if !defined($orig_dev) || ( $^O ne 'MSWin32' && !$orig_ino );
 
     pathempty($dir) or return;
     _bail_if_changed( $dir, $orig_dev, $orig_ino );
